@@ -27,17 +27,20 @@ class Game(object):
     __clear = 'cls' if os.name == 'nt' else 'clear'
 
     COLORS = {
-           2: Fore.GREEN,
-           4: Fore.BLUE + Style.BRIGHT,
-           8: Fore.CYAN,
-          16: Fore.RED,
-          32: Fore.MAGENTA,
-          64: Fore.CYAN,
-         128: Fore.BLUE + Style.BRIGHT,
-         256: Fore.MAGENTA,
-         512: Fore.GREEN,
+        2:    Fore.GREEN,
+        4:    Fore.BLUE + Style.BRIGHT,
+        8:    Fore.CYAN,
+        16:   Fore.RED,
+        32:   Fore.MAGENTA,
+        64:   Fore.CYAN,
+        128:  Fore.BLUE + Style.BRIGHT,
+        256:  Fore.MAGENTA,
+        512:  Fore.GREEN,
         1024: Fore.RED,
         2048: Fore.YELLOW,
+        # just in case people set an higher goal they still have colors
+        4096: Fore.RED,
+        8192: Fore.CYAN,
     }
 
     # see Game#adjustColors
@@ -45,6 +48,7 @@ class Game(object):
     __color_modes = {
         'dark': {
             Fore.BLUE: Fore.WHITE,
+            Fore.BLUE + Style.BRIGHT: Fore.WHITE,
         },
         'light': {
             Fore.YELLOW: Fore.BLACK,
@@ -54,8 +58,8 @@ class Game(object):
     SCORES_FILE = '%s/.term2048.scores' % os.path.expanduser('~')
 
     def __init__(self, scores_file=SCORES_FILE, colors=COLORS,
-            clear_screen=True,
-            mode=None, azmode=False, **kws):
+                 clear_screen=True,
+                 mode=None, azmode=False, **kws):
         """
         Create a new game.
             scores_file: file to use for the best score (default
@@ -99,7 +103,7 @@ class Game(object):
             self.best_score = int(f.readline(), 10)
             f.close()
         except:
-            pass # fail silently
+            pass  # fail silently
 
     def saveBestScore(self):
         """
@@ -112,7 +116,7 @@ class Game(object):
             f.write(str(self.best_score))
             f.close()
         except:
-            pass # fail silently
+            pass  # fail silently
 
     def incScore(self, pts):
         """
@@ -145,7 +149,7 @@ class Game(object):
                     os.system(Game.__clear)
                 else:
                     print("\n")
-                print(self.__str__(margins={'left':4, 'top':4, 'bottom':4}))
+                print(self.__str__(margins={'left': 4, 'top': 4, 'bottom': 4}))
                 if self.board.won() or not self.board.canMove():
                     break
                 m = self.readMove()
@@ -159,7 +163,7 @@ class Game(object):
         print('You won!' if self.board.won() else 'Game Over')
         return self.score
 
-    def getCellStr(self, x, y):
+    def getCellStr(self, x, y):  # TODO: refactor regarding issue #11
         """
         return a string representation of the cell located at x,y.
         """
@@ -167,9 +171,9 @@ class Game(object):
 
         az = {}
         for i in range(1, int(math.log(self.board.goal(), 2))):
-            az[2**i] = chr(i+96)
+            az[2 ** i] = chr(i + 96)
 
-        if c==0 and self.__azmode:
+        if c == 0 and self.__azmode:
             return '.'
         elif c == 0:
             return '  .'
